/*
 *  html.h
 *  mod_musicindex
 *
 *  $Id: http.h 1003 2012-07-31 09:53:17Z varenet $
 *
 *  Created by Regis BOUDIN on Sun Jun 13 2004.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef HTTP_H
#define HTTP_H

#include "mod_musicindex.h"

void treat_get_args(request_rec *r);
void treat_post_args(request_rec *r);

void cookie_and_stream_work(request_rec *r);

#endif	/* HTTP_H */
